@@ -14,14 +14,15 @@ our @EXPORT_OK = (@DSL, @FUNC, @MSN);
 our %EXPORT_TAGS
   = (all => \@EXPORT_OK, dsl => \@DSL, mdn => \@MSN, func => \@FUNC);
 
-our $VERSION = '0.0157';    # VERSION
+our $VERSION = '0.0158';    # VERSION
 
-sub asap : prototype(&@) { Evo::Manager->singleton->asap(@_) }
+sub _manager             { Evo::Manager->singleton }
+sub asap : prototype(&@) { _manager->asap(@_) }
 
-sub dsl_depth : prototype()         { Evo::Manager->singleton->dsl_depth; }
-sub dsl_call : prototype($;@)       { Evo::Manager->singleton->dsl_call(@_); }
-sub dsl_stash : prototype(;$$)      { Evo::Manager->singleton->dsl_stash(@_); }
-sub dsl_check_stash : prototype(;$) { Evo::Manager->singleton->dsl_stash(@_); }
+sub dsl_depth : prototype()         { _manager->dsl_depth; }
+sub dsl_call : prototype($;@)       { _manager->dsl_call(@_); }
+sub dsl_stash : prototype(;$$)      { _manager->dsl_stash(@_); }
+sub dsl_check_stash : prototype(;$) { _manager->dsl_stash(@_); }
 
 sub _mdn { state $mdn = Evo::MDN->new }
 sub mdn_broadcast                           { _mdn->broadcast(@_); }
@@ -47,7 +48,7 @@ Evo - Perl Evo design pattern
 
 =head1 VERSION
 
-version 0.0157
+version 0.0158
 
 =head1 SYNOPSIS
 
