@@ -12,8 +12,9 @@ sub DESTROY {
   my $self = shift;
 
   if ($self->{error}) {
-    my $error = delete $self->{error};
-    $@ and eval { $error->(); 1 } || Carp::carp $@;
+    my $onerror = delete $self->{error};
+    my $err     = $@;
+    $err and eval { $onerror->($err); 1 } || Carp::carp $@;
   }
 
   (delete $self->{always})->() if $self->{always};
@@ -35,7 +36,7 @@ Evo::Guard - A guard
 
 =head1 VERSION
 
-version 0.0157
+version 0.0158
 
 =head1 SYNOPSIS
 
